@@ -29,7 +29,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def rateSet(self, baudrate: float) -> None:
-        """Set the baudrate.
+        """Set the UART baudrate.
 
         Parameters:
             baudrate (float): The baud-rate used by the receiver and transmitter.
@@ -45,7 +45,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def bitsSet(self, databits: int) -> None:
-        """Set the number of data bits.
+        """Set the number of UART data bits.
 
         Parameters:
             databits (int): The number of data-bits used by the receiver and transmitter.
@@ -60,7 +60,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def paritySet(self, parity: int) -> None:
-        """Set parity.
+        """Set UART character parity.
 
         Parameters:
             parity (int): The parity used by the receiver and transmitter:
@@ -79,7 +79,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def stopSet(self, stopbits: float) -> None:
-        """Set number of stop bits.
+        """Set number of UART stop bits.
 
         Parameters:
             stopbits (float): The number of stop-bits used by the receiver and transmitter.
@@ -101,7 +101,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def txSet(self, channel_index: int) -> None:
-        """Set the channel where the outgoing (TX) signal will be transmitted.
+        """Set the channel where the UART's outgoing (TX) signal will be transmitted.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to transmit data.
@@ -114,7 +114,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def rxSet(self, channel_index: int) -> None:
-        """Set the channel where the incoming (RX) signal is received.
+        """Set the channel where the UART's incoming (RX) signal is received.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to receive data.
@@ -127,7 +127,7 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def tx(self, tx_data: bytes) -> None:
-        """Transmit data according to the currently active settings.
+        """Transmit data according to the currently active UART settings.
 
         Parameters:
             tx_data (bytes): The data to be transmitted.
@@ -140,12 +140,11 @@ class DigitalUart(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def rx(self, rx_max: int) -> Tuple[bytes, int]:
-        """Receive data or prepare for reception.
+        """Receive UART data or prepare for reception.
 
         Important:
             This method must be called with value 0 prior to receiving data, to initialize the receiver.
 
-
         Parameters:
             rx_max (int): If 0, initialize the receiver.
 
