@@ -18,14 +18,6 @@ class DwfEnumFilter(enum.Enum):
     In the C API, this type is called 'ENUMFILTER', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfEnumFilter.valueName".
-        """
-        return "DwfEnumFilter." + self.name
-
     All = 0
     """Enumerate all available devices."""
 
@@ -51,14 +43,6 @@ class DwfDeviceID(enum.Enum):
     In the C API, this type is called 'DEVID', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDeviceID.valueName".
-        """
-        return "DwfDeviceID." + self.name
-
     EExplorer  = 1
     """Electronics Explorer devices."""
 
@@ -81,7 +65,7 @@ class DwfDeviceVersion(enum.Enum):
     This type is used exclusively by the |DwfLibrary.deviceEnum.deviceType:link| method to report on a selected device.
 
     Note:
-        The device revision listed here is not complete; it does not cover all devices.
+        The device revision list given here is not complete; it does not cover all devices.
 
         Additionally, the enumeration values :py:attr:`EExplorerC` and :py:attr:`DiscoveryB`
         have identical integer values (2).
@@ -89,14 +73,6 @@ class DwfDeviceVersion(enum.Enum):
     In the C API, this type is called 'DEVVER', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDeviceVersion.valueName".
-        """
-        return "DwfDeviceVersion." + self.name
-
     EExplorerC = 2
     """Electronics Explorer devices, revision C"""
     EExplorerE = 4
@@ -121,14 +97,6 @@ class DwfTriggerSource(enum.Enum):
     In the C API, this type is called 'TRIGSRC', and it is represented as an *unsigned char*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfTriggerSource.valueName".
-        """
-        return "DwfTriggerSource." + self.name
-
     None_ = 0
     """No trigger configured (device starts immediately)."""
 
@@ -201,14 +169,6 @@ class DwfState(enum.Enum):
     In the C API, this type is represented as an *unsigned char*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfState.valueName".
-        """
-        return "DwfState." + self.name
-
     Ready = 0
     """The instrument is idle, waiting to be configured or started."""
 
@@ -246,20 +206,13 @@ class DwfEnumConfigInfo(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfEnumConfigInfo.valueName".
-        """
-        return "DwfEnumConfigInfo." + self.name
-
     TooltipText = -1
-    """Tooltip text (undocumented).
+    """Tooltip text.
 
     Maximum length: 2048 characters.
 
-    Note: This value is not officially documented. It was revealed in a message on the Digilent forum:
+    Note:
+        This value is not officially documented. Its existence  was revealed in a message on the Digilent forum:
         https://forum.digilentinc.com/topic/21720-small-issue-and-questions-about-device-configurations/#comment-62717
     """
 
@@ -268,7 +221,8 @@ class DwfEnumConfigInfo(enum.Enum):
 
     Maximum length: 256 characters.
 
-    Note: This value is not officially documented. It was revealed in a message on the Digilent forum:
+    Note:
+        This value is not officially documented. Its existence was revealed in a message on the Digilent forum:
         https://forum.digilentinc.com/topic/21720-small-issue-and-questions-about-device-configurations/#comment-62717
     """
 
@@ -317,14 +271,6 @@ class DwfAcquisitionMode(enum.Enum):
     In the C API, this type is called 'ACQMODE', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAcquisitionMode.valueName".
-        """
-        return "DwfAcquisitionMode." + self.name
-
     Single = 0
     """Perform a single buffer acquisition.
 
@@ -376,14 +322,6 @@ class DwfAnalogInFilter(enum.Enum):
     In the C API, this type is called 'FILTER", and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogInFilter.valueName".
-        """
-        return "DwfAnalogInFilter." + self.name
-
     Decimate = 0
     """Decimation filter."""
 
@@ -403,14 +341,6 @@ class DwfTriggerType(enum.Enum):
     In the C API, this type is called 'TRIGTYPE', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfTriggerType.valueName".
-        """
-        return "DwfTriggerType." + self.name
-
     Edge = 0
     """Edge trigger type."""
 
@@ -455,25 +385,14 @@ class DwfTriggerSlope(enum.Enum):
 
 
 @enum.unique
-class DwfTriggerLength(enum.Enum):
+class DwfTriggerLengthCondition(enum.Enum):
     """Analog in trigger length condition.
 
     This type is used by the |AnalogIn| instrument to specify the trigger length condition.
 
-    Todo:
-        Decide if we are going to rename this class to DwfTriggerLengthCondition.
-
     In the C API, this type is called 'TRIGLEN', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfTriggerLength.valueName".
-        """
-        return "DwfTriggerLength." + self.name
-
     Less = 0
     """Trigger length condition 'less'."""
 
@@ -497,14 +416,6 @@ class DwfErrorCode(enum.Enum):
     In the C API, this type is called 'DWFERC', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfErrorCode.valueName".
-        """
-        return "DwfErrorCode." + self.name
-
     NoErc = 0
     """No error occurred."""
 
@@ -546,14 +457,6 @@ class DwfAnalogOutFunction(enum.Enum):
     In the C API, this type is called 'FUNC', and it is represented as an *unsigned char*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogOutFunction.valueName".
-        """
-        return "DwfAnalogOutFunction." + self.name
-
     DC        = 0
     Sine      = 1
     Square    = 2
@@ -607,14 +510,6 @@ class DwfAnalogOutNode(enum.Enum):
     In the C API, this type is called 'AnalogOutNode' (without the *Dwf* prefix), and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogOutNode.valueName".
-        """
-        return "DwfAnalogOutNode." + self.name
-
     Carrier = 0
     FM      = 1
     AM      = 2
@@ -630,14 +525,6 @@ class DwfAnalogOutMode(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogOutMode.valueName".
-        """
-        return "DwfAnalogOutMode." + self.name
-
     Voltage = 0
     Current = 1
 
@@ -652,14 +539,6 @@ class DwfAnalogOutIdle(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogOutIdle.valueName".
-        """
-        return "DwfAnalogOutIdle." + self.name
-
     Disable  = 0
     Offset   = 1
     Initial  = 2
@@ -674,14 +553,6 @@ class DwfDigitalInClockSource(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDigitalInClockSource.valueName".
-        """
-        return "DwfDigitalInClockSource." + self.name
-
     Internal  = 0
     External  = 1
     External2 = 2
@@ -696,14 +567,6 @@ class DwfDigitalInSampleMode(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDigitalInSampleMode.valueName".
-        """
-        return "DwfDigitalInSampleMode." + self.name
-
     Simple = 0
     """
     Only digital samples (no noise).
@@ -724,14 +587,6 @@ class DwfDigitalOutOutput(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDigitalOutOutput.valueName".
-        """
-        return "DwfDigitalOutOutput." + self.name
-
     PushPull   = 0
     """Push/Pull"""
     OpenDrain  = 1
@@ -752,14 +607,6 @@ class DwfDigitalOutType(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDigitalOutType.valueName".
-        """
-        return "DwfDigitalOutType." + self.name
-
     Pulse  = 0
     Custom = 1
     Random = 2
@@ -781,14 +628,6 @@ class DwfDigitalOutIdle(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfDigitalOutIdle.valueName".
-        """
-        return "DwfDigitalOutIdle." + self.name
-
     Init = 0
     """Same as initial value of selected output pattern."""
 
@@ -811,14 +650,6 @@ class DwfAnalogImpedance(enum.Enum):
     In the C API, this type is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfAnalogImpedance.valueName".
-        """
-        return "DwfAnalogImpedance." + self.name
-
     Impedance           =  0  # Ohms
     ImpedancePhase      =  1  # Radians
     Resistance          =  2  # Ohms
@@ -845,14 +676,6 @@ class DwfParameter(enum.Enum):
     In the C API, this type is called 'DwfParam', and it is represented as an *int*.
     """
 
-    def __repr__(self):
-        """Override the default Enum implementation which returns a strangely formatted string.
-
-        Returns:
-            str: A string representation of the enum value, as "DwfParameter.valueName".
-        """
-        return "DwfParameter." + self.name
-
     UsbPower = 2
     """USB power behavior if AUX power is connected.
 
@@ -867,9 +690,11 @@ class DwfParameter(enum.Enum):
     LedBrightness = 3
     """Set multicolor LED brightness.
 
-    The Digital Discovery features a multi-color LED that normally emits bright blue light.
+    The Digital Discovery features a multi-color LED. It is normally blue in case the device is not
+    currently controlled by software, or green if it is.
 
-    Setting this parameter from 0 to 100 changes the LED's color to green and sets its relative brightness, in percents.
+    Setting this parameter from 0 to 100 changes the LED's relative brightness, in percents. This can be
+    useful, for example, in a lab with sensitive optics that would preferably be completely dark.
 
     On the Analog Discovery 2, this setting has no effect.
     """
