@@ -58,9 +58,10 @@ class DwfLibrary:
                 raise PyDwfError("Unable to verify library version")
             actual_dwf_version = c_version.value.decode()
             if actual_dwf_version != expected_dwf_version:
-                raise PyDwfError("DWF library version mismatch: pydwf module expects {},"
-                                 " but actual library is version {}".format(
-                    expected_dwf_version, actual_dwf_version))
+                raise PyDwfError(
+                    "DWF library version mismatch: pydwf module expects {},"
+                    " but actual library is version {}".format(
+                     expected_dwf_version, actual_dwf_version))
 
         self._annotate_function_signatures(lib)
 
